@@ -1,6 +1,6 @@
 import unittest
-from holger.command import Command
-from holger.multiprocessing import Todo
+from tamarin.command import Command
+from tamarin.multiprocessing import Todo
 
 
 class LightTurnOn(Command):
